<?php
/**
 * Medical Portfolio Theme Customizer.
 *
 * @package Medical Portfolio
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if ( ! class_exists( 'WP_Customize_Control' ) )
    return NULL;

/**
 * A class to create a dropdown for all categories in your wordpress site
 */
 class medical_portfolio_Category_Dropdown_Custom_Control extends WP_Customize_Control
 {
    private $cats = false;
    public function __construct($manager, $id, $args = array(), $options = array())
    {
        $this->cats = get_categories($options);
        parent::__construct( $manager, $id, $args );
    }

    /**
     * Render the content of the category dropdown
     *
     * @return HTML
     */
    public function render_content()
       {
            if(!empty($this->cats))
            {
                ?>
                    <label>
                      <span class="customize-category-select-control"><?php echo esc_html( $this->label ); ?></span>
                      <select <?php $this->link(); ?>>
                           <?php
                                foreach ( $this->cats as $cat )
                                {
                                    printf('<option value="%s" %s>%s</option>', $cat->term_id, selected($this->value(), $cat->term_id, false), $cat->name);
                                }
                           ?>
                      </select>
                    </label>
                <?php
            }
       }
 }
 
function medical_portfolio_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';	
	$wp_customize->get_section( 'title_tagline'  )->title		= __('Site Titles & Logo','medical-portfolio');
	//$wp_customize->get_control( 'header_text'  )->label			= __('Display Site Title','medical-portfolio');
	$wp_customize->get_section( 'title_tagline'  )->priority	= 10;
	$wp_customize->get_section( 'colors'  )->title				= __('Background Color','medical-portfolio');
	$wp_customize->get_section( 'colors'  )->panel				= 'medical_portfolio_panel_design';
	$wp_customize->get_section( 'background_image'  )->panel	= 'medical_portfolio_panel_design';


	// Theme important links started
   class medical_portfolio_Important_Links extends WP_Customize_Control {

      public $type = "medical-portfolio-important-links";

      public function render_content() {
         //Add Theme instruction
		 $medical_portfolio_features = array(
		 'Features' => array(
               'text' => __('Features 1', 'medical-portfolio'),
               'text' => __('Features 2', 'medical-portfolio'),
               'text' => __('Features 3', 'medical-portfolio'),
               'text' => __('Features 4', 'medical-portfolio'),
            ), 
		 
		 );
		 echo '<ul><b>
			<li>' . esc_attr__( '* Fully Mobile Responsive', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* More Options in Panel', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Customize Theme Color', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* WooCommerce & bbPress Support Control', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* SEO Optimized', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Control Individual Meta Option like: Category, date, Author, Tags etc. ', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Full Support', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Google Fonts', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Theme Color Customization', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Custom CSS', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Website Layout', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Select Number of Columns', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* Website Width Control', 'medical-portfolio' ) . '</li>
			<li>' . esc_attr__( '* News Ticker with category control', 'medical-portfolio' ) . '</li>
			</b></ul>
		 ';
         $important_links = array(
		 
            'theme-info' => array(
               'link' => esc_url('https://www.insertcart.com/product/medical-portfolio-pro/'),
               'text' => __('Medical Portfolio Pro', 'medical-portfolio'),
            ),
            'support' => array(
               'link' => esc_url('https://www.insertcart.com/contact-us/'),
               'text' => __('Contact us', 'medical-portfolio'),
            ),         
			'Documentation' => array(
               'link' => esc_url('https://www.insertcart.com/medical-portfolio-theme-setup-guide/'),
               'text' => __('Documentation', 'medical-portfolio'),
            ),			 
         );
         foreach ($important_links as $important_link) {
            echo '<p><a target="_blank" href="' . esc_url($important_link['link']) . '" >' . esc_attr($important_link['text']) . ' </a></p>';
         }
         }
  }
      $wp_customize->add_section('medical_portfolio_important_links', array(
      'priority' => 1,
      'title' => __('Upgrade to Pro', 'medical-portfolio'),
   ));

   $wp_customize->add_setting('medical_portfolio_important_links', array(
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'medical_portfolio_links_sanitize'
   ));

   $wp_customize->add_control(new medical_portfolio_Important_Links($wp_customize, 'important_links', array(
      'section' => 'medical_portfolio_important_links',
      'settings' => 'medical_portfolio_important_links'
   )));

// create an empty array
$cats = array();
 
// we loop over the categories and set the names and
// labels we need
foreach ( get_categories() as $categoriesi => $categoryy ){
    $cats[$categoryy->term_id] = $categoryy->name;
}


/**************************************************
* Show Front Page
***************************************************/
	$wp_customize->add_panel('medical_portfolio_frontpageindex',
		array(
			'priority' 			=> 13,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Website Front Page', 'medical-portfolio' ),
			'description' 		=> __( 'Website Default Front Page options', 'medical-portfolio' ),
		)
	);
	

	
	
// Front Page Enable
$wp_customize->add_section( 'medical_portfolio_frontpage' , array(
    'title'      => __( 'Enable or Disable Front Page', 'medical-portfolio' ),
	'description' 		=> __( 'Enable or Disable default front page in website ', 'medical-portfolio' ),
    'priority'   => 1,
   'panel'			=> 'medical_portfolio_frontpageindex'
) );   


$wp_customize->add_setting('medical_portfolio_enablefrontpage',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
	$wp_customize->add_control('medical_portfolio_enablefrontpage',
    array(
        'type' => 'radio',
		'settings'   => 'medical_portfolio_enablefrontpage',
        'section' => 'medical_portfolio_frontpage',
        'choices' => array(
            'enable' => __('Enable','medical-portfolio'),
            'disable' => __('Disable','medical-portfolio'),
        ) ));

		
// Woocommerce Section		
		
$wp_customize-> add_section('medical_portfolio_frontpage_woo',
    array(
    	'title'			=> __('Front Page WooCommerce','medical-portfolio'),
    	'description'	=> __('Only for front page Woocommerce settings. Star mark as featured product from woocommerce products list','medical-portfolio'),
    	'priority'		=> 3,
    	'panel'			=> 'medical_portfolio_frontpageindex'
    	)
    );
    
	
$wp_customize->add_setting('medical_portfolio_frontwoo',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
	$wp_customize->add_control('medical_portfolio_frontwoo',
    array(
        'type' => 'radio',
		'label'        => __( 'Enable or Disable WooCommerce', 'medical-portfolio' ),
		'settings'   => 'medical_portfolio_frontwoo',
        'section' => 'medical_portfolio_frontpage_woo',
        'choices' => array(
            'enable' => __('Enable','medical-portfolio'),
            'disable' => __('Disable','medical-portfolio'),
        ) ));
	
	$wp_customize->add_setting('medical_portfolio_woo_sec_text',
	array(
		'default'		=> 'Featured Products',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_woo_sec_text',
	        array(
			'label'        => __( 'Title of WooCommerce', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_woo',
	            'settings' => 'medical_portfolio_woo_sec_text',
	            'type' => 'text'
	        )
	);

	$wp_customize->add_setting('medical_portfolio_woo_pronum',
	array(
		'default'		=> '8',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_woo_pronum',
	        array(
			'label'        => __( 'Number of product to show. Default: 8', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_woo',
	            'settings' => 'medical_portfolio_woo_pronum',
	            'type' => 'text'
	        )
	);
		
// Posts Sections		
		
$wp_customize-> add_section('medical_portfolio_frontpage_post',
    array(
    	'title'			=> __('Front Page Posts','medical-portfolio'),
    	'description'	=> __('Only for front page posts.','medical-portfolio'),
    	'priority'		=> 3,
    	'panel'			=> 'medical_portfolio_frontpageindex'
    	)
    );
    
	
$wp_customize->add_setting('medical_portfolio_enablefrontpost',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
	$wp_customize->add_control('medical_portfolio_enablefrontpost',
    array(
        'type' => 'radio',
		'label'        => __( 'Enable or Disable Posts', 'medical-portfolio' ),
		'settings'   => 'medical_portfolio_enablefrontpost',
        'section' => 'medical_portfolio_frontpage_post',
        'choices' => array(
            'enable' => __('Enable','medical-portfolio'),
            'disable' => __('Disable','medical-portfolio'),
        ) ));
	
	$wp_customize->add_setting('medical_portfolio_post_sec_text',
	array(
		'default'		=> 'Latest Blog Posts',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_post_sec_text',
	        array(
			'label'        => __( 'Title of Posts', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_post',
	            'settings' => 'medical_portfolio_post_sec_text',
	            'type' => 'text'
	        ));

	$wp_customize->add_setting('medical_portfolio_post_pronum',
	array(
		'default'		=> '4',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_post_pronum',
	        array(
			'label'        => __( 'Number of post to show. Default: 4', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_post',
	            'settings' => 'medical_portfolio_post_pronum',
	            'type' => 'text'
	        )
	);
				

$wp_customize->add_setting('medical_portfolio_post_prodate',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_post_prodate',
	 array (                             
		'type' => 'radio',
		'label' => __('Date stamp in post','medical-portfolio'),
		'settings'   => 'medical_portfolio_post_prodate',
		'section' => 'medical_portfolio_frontpage_post',
		'choices' => array(
		'enable' => __('Enable','medical-portfolio'),
		'disable' => __('Disable','medical-portfolio'),
	 ) 
	 ));

/**************************************************
* Block Grid
***************************************************/
//featured posts 2
	
	$wp_customize->add_section( 'profile_panel_featuredtwo' , array(
	'title'      => __( 'Featured Posts Block', 'medical-portfolio' ),
	'description' 		=> __( 'Top Header featured posts section, Select Category for featured post to display', 'medical-portfolio' ),
	'panel' => 'medical_portfolio_frontpageindex',
	'priority'   => 1,
	) );  

$wp_customize->add_setting('medical_portfolio_featured_sectiontwo',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_featured_sectiontwo',
                         array (                             
							'type' => 'radio',
							'label' => __('Enable or Disable Featured Section','medical-portfolio'),
							'settings'   => 'medical_portfolio_featured_sectiontwo',
							'section' => 'profile_panel_featuredtwo',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));	
	$wp_customize->add_setting( 'profile_featuredtwocate', array(
	'default' => 1,
	'sanitize_callback' => 'absint'
	) );

	$wp_customize->add_control( 'profile_featurecat_controltwo', array(
	'settings' => 'profile_featuredtwocate',
	'label' => __('Select Category','medical-portfolio'),
	'type' => 'select',
	'choices' => $cats,
	'section' => 'profile_panel_featuredtwo',  // depending on where you want it to be
	) );
/**************************************************
* Profile Blocks
***************************************************/
	$wp_customize->add_section( 'medical_panel_blockgrids' , array(
    'title'      => __( 'Profile Blocks', 'medical-portfolio' ),
	'description' 		=> __( 'Show 4 Block on Front Page', 'medical-portfolio' ),
	'panel' => 'medical_portfolio_frontpageindex',
    'priority'   => 17,
) );
	//Show or Hide top bar
	$wp_customize->add_setting('medical_blockgrid_enble',	
		array(
			'default'			=> 'disable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
			
	));
	$wp_customize->add_control('medical_blockgrid_enble',
		 array (                             
			'type' => 'radio',
			'label' => __('Show or hide Blocks','medical-portfolio'),
			'settings'   => 'medical_blockgrid_enble',
			'section' => 'medical_panel_blockgrids',
			'choices' => array(
			'enable' => __('Enable','medical-portfolio'),
			'disable' => __('Disable','medical-portfolio'),
		 )
		 ));
		 
	$wp_customize->add_setting('medical_portfolio_blocktitle',
	array(
		'default'		=> 'Our Profiles',
		'sanitize_callback'	=> 'sanitize_text_field'		
		));
	
	$wp_customize->add_control('medical_portfolio_blocktitle',
	        array(
				'label'   => __( 'Blocks Title', 'medical-portfolio' ),
	            'section' => 'medical_panel_blockgrids',
	            'settings' => 'medical_portfolio_blocktitle',
	            'type' => 'text'
	        ));	 
		 
	$wp_customize->add_setting( 'frontblockbg' , array(
		'default'     => '#ffffff',
		'transport'   => 'refresh',
		'sanitize_callback'	=> 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'frontblockbg', array(
		'label'        => __( 'Block Background Color', 'medical-portfolio' ),
		'section'    => 'medical_panel_blockgrids',
		'settings'   => 'frontblockbg',
		) ) );

	$wp_customize->add_setting( 'frontblocktext' , array(
		'default'     => '#555555',
		'transport'   => 'refresh',
		'sanitize_callback'	=> 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'frontblocktext', array(
		'label'        => __( 'Block Text Color', 'medical-portfolio' ),
		'section'    => 'medical_panel_blockgrids',
		'settings'   => 'frontblocktext',
		) ) );
	
	//Block Photo
	
	$wp_customize->add_setting('medical_blockgrid_photo',
		array(
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback' => 'absint'
		)
	);
                $wp_customize->add_control(
		new WP_Customize_Cropped_Image_Control(	$wp_customize,	'medical_blockgrid_photo',
			array(
				'settings'		=> 'medical_blockgrid_photo',
				'section'		=> 'medical_panel_blockgrids',
				'flex_width'  => true,
				'flex_height' => true, 
				'width'       => 150,
				'height'      => 150,
				'label'			=> __('Upload Block Photo', 'medical-portfolio' )
				
			)));
	
		//Block name
	$wp_customize->add_setting('medical_blockgrid_name',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_name',
		 array (                             
			'type' => 'text',
			'label' => __('Name of Block','medical-portfolio'),
			'settings'   => 'medical_blockgrid_name',
			'section' => 'medical_panel_blockgrids',
		 ));
		//description
	$wp_customize->add_setting('medical_blockgrid_description',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_description',
		 array (                             
			'type' => 'textarea',
			'label' => __('Description','medical-portfolio'),
			'settings'   => 'medical_blockgrid_description',
			'section' => 'medical_panel_blockgrids',
		 ));
		//Block Photo
	
	$wp_customize->add_setting('medical_blockgrid_photo2',
		array(
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback' => 'absint'
		)
	);
                $wp_customize->add_control(
		new WP_Customize_Cropped_Image_Control(	$wp_customize,	'medical_blockgrid_photo2',
			array(
				'settings'		=> 'medical_blockgrid_photo2',
				'section'		=> 'medical_panel_blockgrids',
				'flex_width'  => false,
				'flex_height' => true, 
				'width'       => 150,
				'height'      => 150,
				'label'			=> __('Upload Block Photo', 'medical-portfolio' )
				
			)));
	
		//Block name
	$wp_customize->add_setting('medical_blockgrid_name2',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_name2',
		 array (                             
			'type' => 'text',
			'label' => __('Name of Block','medical-portfolio'),
			'settings'   => 'medical_blockgrid_name2',
			'section' => 'medical_panel_blockgrids',
		 ));
		//description
	$wp_customize->add_setting('medical_blockgrid_description2',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_description2',
		 array (                             
			'type' => 'textarea',
			'label' => __('Description','medical-portfolio'),
			'settings'   => 'medical_blockgrid_description2',
			'section' => 'medical_panel_blockgrids',
		 )); 
//Block Photo
	
	$wp_customize->add_setting('medical_blockgrid_photo3',
		array(
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback' => 'absint'
		)
	);
       $wp_customize->add_control(
		new WP_Customize_Cropped_Image_Control(	$wp_customize,	'medical_blockgrid_photo3',
			array(
				'settings'		=> 'medical_blockgrid_photo3',
				'section'		=> 'medical_panel_blockgrids',
				'flex_width'  => false,
				'flex_height' => true, 
				'width'       => 150,
				'height'      => 150,
				'label'			=> __('Upload Block Photo', 'medical-portfolio' )
				
			)));
	
		//Block name
	$wp_customize->add_setting('medical_blockgrid_name3',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_name3',
		 array (                             
			'type' => 'text',
			'label' => __('Name of Block','medical-portfolio'),
			'settings'   => 'medical_blockgrid_name3',
			'section' => 'medical_panel_blockgrids',
		 ));
		//description
	$wp_customize->add_setting('medical_blockgrid_description3',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_description3',
		 array (                             
			'type' => 'textarea',
			'label' => __('Description','medical-portfolio'),
			'settings'   => 'medical_blockgrid_description3',
			'section' => 'medical_panel_blockgrids',
		 ));
//Block Photo
	$wp_customize->add_setting('medical_blockgrid_photo4',
		array(
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback' => 'absint'
		)
	);
                $wp_customize->add_control(
		new WP_Customize_Cropped_Image_Control(	$wp_customize,	'medical_blockgrid_photo4',
			array(
				'settings'		=> 'medical_blockgrid_photo4',
				'section'		=> 'medical_panel_blockgrids',
				'flex_width'  => false,
				'flex_height' => true, 
				'width'       => 150,
				'height'      => 150,
				'label'			=> __('Upload Block Photo', 'medical-portfolio' )
				
			)));
	
		//Block name
	$wp_customize->add_setting('medical_blockgrid_name4',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'
			
	));
	$wp_customize->add_control('medical_blockgrid_name4',
		 array (                             
			'type' => 'text',
			'label' => __('Name of Block','medical-portfolio'),
			'settings'   => 'medical_blockgrid_name4',
			'section' => 'medical_panel_blockgrids',
		 ));
		//description
	$wp_customize->add_setting('medical_blockgrid_description4',	
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',			
			'sanitize_callback'	=> 'wp_kses_post'			
	));
	$wp_customize->add_control('medical_blockgrid_description4',
		 array (                             
			'type' => 'textarea',
			'label' => __('Description','medical-portfolio'),
			'settings'   => 'medical_blockgrid_description4',
			'section' => 'medical_panel_blockgrids',
		 ));
/**************************************************
* Fonts
***************************************************/
$font_array = array('Raleway','Khula','Open Sans','Indie Flower','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Fjalla One','PT Sans Narrow','Poiret One','Passion One','Arvo','Inconsolata','Shadows Into Light','Pacifico','Dancing Script','Architects Daughter','Sigmar One','Righteous','Amatic SC','Orbitron','Chewy','Lobster Two','Gloria Hallelujah','Lekton','Almendra Display','Swanky and Moo Moo','Hanalei Fill','Uncial Antiqua','Rouge Script','Engagement','Bonbon','Caesar Dressing','Kenia','Lemon','Stardos Stencil','Bilbo','Macondo','Delius Unicase','Butcherman','Monoton','Nosifer','Codystar','Fontdiner Swanky','Diplomata SC','Snowburst One','Faster One','Rock Salt','Eater');
$fonts = array_combine($font_array, $font_array);
// Body Fonts
	$wp_customize->add_section( 'medical_portfolio_panel_bodyfonts' , array(
    'title'      => __( 'Body Fonts', 'medical-portfolio' ),
	'panel'			=> 'medical_portfolio_panel_advance',
    'priority'   => 1,
) );	
$wp_customize->add_setting(
	'medical_portfolio_title_font',
	array(
		'default'=> 'Open Sans',
		'sanitize_callback' => 'medical_portfolio_sanitize_gfont' 
		)
);
$wp_customize->add_control(
	'medical_portfolio_title_font',array(
			'label' => __('Title','medical-portfolio'),
			'settings' => 'medical_portfolio_title_font',
			'section'  => 'medical_portfolio_panel_bodyfonts',
			'type' => 'select',
			'choices' => $fonts,
		)
);
$wp_customize->add_setting(
		'medical_portfolio_body_font',
			array(	'default'=> 'Open Sans',
					'sanitize_callback' => 'medical_portfolio_sanitize_gfont' )
	);

$wp_customize->add_control(
		'medical_portfolio_body_font',array(
				'label' => __('Body','medical-portfolio'),
				'settings' => 'medical_portfolio_body_font',
				'section'  => 'medical_portfolio_panel_bodyfonts',
				'type' => 'select',
				'choices' => $fonts
			)
	);
/**************************************************
* Tinymce Editor - Header
***************************************************/
  
  $wp_customize->add_section('headerinfo_section' ,  array(
    'title' => __('Header Info Area', 'medical-portfolio'),
	'panel'			=> 'medical_portfolio_panel_advance',
    'priority' => 100
  ));
  
  
  $wp_customize->add_setting('header_enable',	
	array(
		'default'			=> 'disable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('header_enable',
                         array (                             
							'type' => 'radio',
							'label' => __('Top Header Bar','medical-portfolio'),
							'settings'   => 'header_enable',
							'section' => 'headerinfo_section',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));

$wp_customize->add_setting(	'header_infoleft',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'wp_kses_post'
	));

$wp_customize->add_control(	'header_infoleft',
	array(
		'section' => 'headerinfo_section',
		'label' => __('Left side text','medical-portfolio'),
		'settings' => 'header_infoleft',
		'type' => 'textarea'
	));

$wp_customize->add_setting(	'header_inforight',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'wp_kses_post'
	));

$wp_customize->add_control(	'header_inforight',
	array(
		'section' => 'headerinfo_section',
		'label' => __('Right side text','medical-portfolio'),
		'settings' => 'header_inforight',
		'type' => 'textarea'
	));

	
/**************************************************
* Post Settings
***************************************************/
// Post Settings
	$wp_customize->add_section( 'medical_portfolio_panel_postsettings' , array(
    'title'      => __( 'Post Settings', 'medical-portfolio' ),
	//'panel'			=> 'medical_portfolio_panel_advance',
    'priority'   => 2,
) );


$wp_customize->add_setting('random_post',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('random_post',
                         array (                             
							'type' => 'radio',
							'label' => __('Random Post Below Post','medical-portfolio'),
							'settings'   => 'random_post',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));						
$wp_customize->add_setting('medical_portfolio_author_profile',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_author_profile',
                         array (                             
							'type' => 'radio',
							'label' => __('Show Author Profile in Post and Pages','medical-portfolio'),
							'settings'   => 'medical_portfolio_author_profile',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
	
$wp_customize->add_setting('singlepost_thumb',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_thumb',
                         array (                             
							'type' => 'radio',
							'label' => __('Thumbnail in Single Post','medical-portfolio'),
							'settings'   => 'singlepost_thumb',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
$wp_customize->add_setting('singlepost_date',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_date',
                         array (                             
							'type' => 'radio',
							'label' => __('Date in single post','medical-portfolio'),
							'settings'   => 'singlepost_date',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));						 
$wp_customize->add_setting('singlepost_authortitle',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_authortitle',
                         array (                             
							'type' => 'radio',
							'label' => __('Author name in single post','medical-portfolio'),
							'settings'   => 'singlepost_authortitle',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));	
$wp_customize->add_setting('singlepost_cate',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_cate',
                         array (                             
							'type' => 'radio',
							'label' => __('Category in single post','medical-portfolio'),
							'settings'   => 'singlepost_cate',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
$wp_customize->add_setting('singlepost_tags',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_tags',
                         array (                             
							'type' => 'radio',
							'label' => __('Tags in single post','medical-portfolio'),
							'settings'   => 'singlepost_tags',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));						 
/**************************************************
* WooCommerce
***************************************************/
// Woocommerce
	$wp_customize->add_section( 'medical_portfolio_woo_section' , array(
    'title'      => __( 'WooCommerce', 'medical-portfolio' ),
	//'panel'			=> 'medical_portfolio_panel_design',
    'priority'   => 67,
) );
$wp_customize->add_setting('medical_portfolio_woo_myaccount',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'transport'   => 'post',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_myaccount', array (                             
				'type' => 'radio',
				'label' => __('My Account/ Login','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_myaccount',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));
$wp_customize->add_setting('medical_portfolio_woo_cart',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'transport'   => 'post',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_cart', array (                             
				'type' => 'radio',
				'label' => __('Cart','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_cart',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));
			 
			 
$wp_customize->add_setting('medical_portfolio_woo_removemeta',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'transport'   => 'post',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_removemeta', array (                             
				'type' => 'radio',
				'label' => __('Remove Category & Tags from Product','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_removemeta',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Hide','medical-portfolio'),
				'disable' => __('Show','medical-portfolio'),
			 )
			 ));			 
// Woocommerce Settings
$wp_customize->add_setting('medical_portfolio_woo_lightbox',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_lightbox', array (                             
				'type' => 'radio',
				'label' => __('LightBox Open Images','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_lightbox',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));
$wp_customize->add_setting('medical_portfolio_woo_zoom',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_zoom', array (                             
				'type' => 'radio',
				'label' => __('Zoom Product Images','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_zoom',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));	
$wp_customize->add_setting('medical_portfolio_woo_slider',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_slider', array (                             
				'type' => 'radio',
				'label' => __('Slide Product Images','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_slider',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));	
/**************************************************
* Footer Copyright
***************************************************/
	$wp_customize-> add_section(
    'medical_portfolio_custom_footer',
    array(
    	'title'			=> __('Custom Footer Text','medical-portfolio'),
    	'description'	=> __('Enter your Own Copyright Text.','medical-portfolio'),
    	'priority'		=> 3,
    	'panel'			=> 'medical_portfolio_panel_advance'
    	)
    );
    
	$wp_customize->add_setting(
	'medical_portfolio_footer_text',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control(	 
	       'medical_portfolio_footer_text',
	        array(
	            'section' => 'medical_portfolio_custom_footer',
	            'settings' => 'medical_portfolio_footer_text',
	            'type' => 'text'
	        )
	);
	
/**************************************************
* Social
***************************************************/
	// Social Icons
	$wp_customize->add_section('medical_portfolio_social_section', array(
			'title' => __('Social Icons','medical-portfolio'),
			'priority' => 44 ,
				'panel'	=> 'medical_portfolio_panel_advance'
	));
	
	$social_networks = array( //Redefinied in Sanitization Function.
					'none' => __('-','medical-portfolio'),
					'facebook' => __('Facebook','medical-portfolio'),
					'twitter' => __('Twitter','medical-portfolio'),
					'google' => __('Google','medical-portfolio'),
					'instagram' => __('Instagram','medical-portfolio'),
					'rss' => __('RSS Feeds','medical-portfolio'),
					'vine' => __('Vine','medical-portfolio'),
					'vimeo' => __('Vimeo','medical-portfolio'),
					'youtube' => __('Youtube','medical-portfolio'),
					'etsy' => __('Etsy','medical-portfolio'),
					'flickr' => __('Flickr','medical-portfolio'),
					'whatsapp' => __('WhatsApp','medical-portfolio'),
					'vk' => __('VK','medical-portfolio'),
					'wordpress' => __('WordPress','medical-portfolio'),
					'tumblr' => __('Tumblr','medical-portfolio'),
					'telegram' => __('Telegram','medical-portfolio'),
					'windows' => __('Windows','medical-portfolio'),
					'tripadvisor' => __('Trip Advisor','medical-portfolio'),
					'stumbleupon' => __('StumbleUpon','medical-portfolio'),
					'stack-overflow' => __('Stack Overflow','medical-portfolio'),
					'snapchat-ghost' => __('Snapchat','medical-portfolio'),
					'skype' => __('Skype','medical-portfolio'),
					'reddit-alien' => __('Reddit','medical-portfolio'),
					'github' => __('Github','medical-portfolio'),
					'dropbox' => __('Dropbox','medical-portfolio'),
					'btc' => __('Bitcoin','medical-portfolio'),
					'apple' => __('Apple','medical-portfolio'),
					'amazon' => __('Amazon','medical-portfolio'),
					'android' => __('Android','medical-portfolio'),
					'pinterest-p' => __('Pinterest','medical-portfolio'),
				);
				
	$social_count = count($social_networks);
				
	for ($x = 1 ; $x <= ($social_count - 3) ; $x++) :
			
		$wp_customize->add_setting(
			'medical_portfolio_social_'.$x, array(
				'sanitize_callback' => 'medical_portfolio_sanitize_social',
				'default' => 'none'
			));

		$wp_customize->add_control( 'medical_portfolio_social_'.$x, array(
					'settings' => 'medical_portfolio_social_'.$x,
					'label' => __('Icon ','medical-portfolio').$x,
					'section' => 'medical_portfolio_social_section',
					'type' => 'select',
					'choices' => $social_networks,			
		));
		
		$wp_customize->add_setting(
			'medical_portfolio_social_url'.$x, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'medical_portfolio_social_url'.$x, array(
					'settings' => 'medical_portfolio_social_url'.$x,
					'description' => __('Icon ','medical-portfolio').$x.__(' Url','medical-portfolio'),
					'section' => 'medical_portfolio_social_section',
					'type' => 'url',
					'choices' => $social_networks,			
		));
		
	endfor;
	
	function medical_portfolio_sanitize_social( $input ) {
		$social_networks = array(
					'none' ,
					'facebook',
					'twitter',
					'google',
					'instagram',
					'rss',
					'vine',
					'vimeo',
					'youtube',
					'etsy',
					'flickr',
					'whatsapp',
					'vk',
					'wordpress',
					'tumblr',
					'telegram',
					'windows',
					'tripadvisor',
					'stumbleupon',
					'stack-overflow',
					'snapchat-ghost',
					'skype',
					'reddit-alien',
					'github',
					'dropbox',
					'btc',
					'apple',
					'amazon',
					'android',
					'pinterest-p'
				);
		if ( in_array($input, $social_networks) )
			return $input;
		else
			return '';	
	}	
	
	


/**************************************************
* Customizer Panels
***************************************************/	
	$wp_customize->add_panel('medical_portfolio_panel_design',
		array(
			'priority' 			=> 12,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Color, Design', 'medical-portfolio' ),
			'description' 		=> __( 'Configure color and layout settings for the medical_portfolio Theme', 'medical-portfolio' ),
		)
	);
	$wp_customize->add_panel('medical_portfolio_panel_advance',
		array(
			'priority' 			=> 13,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Advance Settings', 'medical-portfolio' ),
			'description' 		=> __( 'Advance Settings related to footer copyright and Enable options', 'medical-portfolio' ),
		)
	);
		
		
		
/**********************************
Slider
************************************/
$wp_customize->add_panel('medical_portfolio_panel_slider',
		array(
			'priority' 			=> 13,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Slider', 'medical-portfolio' ),
			'description' 		=> __( 'Image Slider on header', 'medical-portfolio' ),
		)
	);		
$wp_customize->add_section('medical_portfolio_slider_sec' ,  array(
    'title' => __('Slider Settings', 'medical-portfolio'),
	'panel'			=> 'medical_portfolio_panel_slider',
    'priority' => 100
  ));
  
  $wp_customize->add_setting('medical_portfolio_slider_enable',	
	array(
		'default'			=> 'disable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_slider_enable',
                         array (                             
							'type' => 'radio',
							'label' => __('Slider Settings','medical-portfolio'),
							'settings'   => 'medical_portfolio_slider_enable',
							'section' => 'medical_portfolio_slider_sec',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));	
	
$wp_customize->add_setting('medical_portfolio_totalslide',
	array(
		'default'		=> '4',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_totalslide',
	        array(
			'label'        => __( 'Number of Slide to show. Max: 4', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_slider_sec',
	            'settings' => 'medical_portfolio_totalslide',
	            'type' => 'text'
	        )
	);	
/*********slide 1*****************/
$wp_customize->add_section('medical_portfolio_slider1', 
array(
    'title' => __('Slide 1', 'medical-portfolio'),
    'description'=> sprintf(__('Slide 1 Details', 'medical-portfolio')),
	'panel'			=> 'medical_portfolio_panel_slider',
    'priority' => 100
    ));
						 
	$wp_customize -> add_setting('slideimg1', array(
		'default' => '', 
		'type' => 'theme_mod',
		'sanitize_callback' => 'medical_portfolio_sanitize_image'

	));

	$wp_customize -> add_control(new WP_Customize_Image_Control($wp_customize, 'slideimg1', array(
		'label' => __( 'Slide 1', 'medical-portfolio'),
		'section' => 'medical_portfolio_slider1',
		'settings' => 'slideimg1',
		'priority' => 2
	))); 


	
	$wp_customize->add_setting( 'slidebntext1', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebntext1', array(
			'settings'		=> 'slidebntext1',
			'section'		=> 'medical_portfolio_slider1',
			'type'			=> 'textarea',
			'label'			=> __( 'Image Text', 'medical-portfolio' ),
		)
	);
	
	$wp_customize->add_setting( 'slidebnlink1', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebnlink1', array(
			'settings'		=> 'slidebnlink1',
			'section'		=> 'medical_portfolio_slider1',
			'type'			=> 'url',
			'label'			=> __( 'Link', 'medical-portfolio' ),
		)
	);
/*********slide 2*****************/
$wp_customize->add_section('medical_portfolio_slider2', 
array(
    'title' => __('Slide 2', 'medical-portfolio'),
    'description'=> sprintf(__('Slide 2 Details', 'medical-portfolio')),
	'panel'			=> 'medical_portfolio_panel_slider',
    'priority' => 100
    ));
						 
	$wp_customize -> add_setting('slideimg2', array(
		'default' => '', 
		'type' => 'theme_mod',
		'sanitize_callback' => 'medical_portfolio_sanitize_image'

	));

	$wp_customize -> add_control(new WP_Customize_Image_Control($wp_customize, 'slideimg2', array(
		'label' => __( 'Slide 2', 'medical-portfolio'),
		'section' => 'medical_portfolio_slider2',
		'settings' => 'slideimg2',
		'priority' => 2
	))); 

	
	$wp_customize->add_setting( 'slidebntext2', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebntext2', array(
			'settings'		=> 'slidebntext2',
			'section'		=> 'medical_portfolio_slider2',
			'type'			=> 'textarea',
			'label'			=> __( 'Image Text', 'medical-portfolio' ),
		)
	);
	
	$wp_customize->add_setting( 'slidebnlink2', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebnlink2', array(
			'settings'		=> 'slidebnlink2',
			'section'		=> 'medical_portfolio_slider2',
			'type'			=> 'url',
			'label'			=> __( 'Link', 'medical-portfolio' ),
		)
	);	
/****************Slide 3******************/
$wp_customize->add_section('medical_portfolio_slider3', 
array(
    'title' => __('Slide 3', 'medical-portfolio'),
    'description'=> sprintf(__('Slide 3 Details', 'medical-portfolio')),
	'panel'			=> 'medical_portfolio_panel_slider',
    'priority' => 100
    ));
						 
	$wp_customize -> add_setting('slideimg3', array(
		'default' => '', 
		'type' => 'theme_mod',
		'sanitize_callback' => 'medical_portfolio_sanitize_image'

	));

	$wp_customize -> add_control(new WP_Customize_Image_Control($wp_customize, 'slideimg3', array(
		'label' => __( 'Slide 3', 'medical-portfolio'),
		'section' => 'medical_portfolio_slider3',
		'settings' => 'slideimg3',
		'priority' => 2
	))); 

	
	$wp_customize->add_setting( 'slidebntext3', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebntext3', array(
			'settings'		=> 'slidebntext3',
			'section'		=> 'medical_portfolio_slider3',
			'type'			=> 'textarea',
			'label'			=> __( 'Image Text', 'medical-portfolio' ),
		)
	);
	
	$wp_customize->add_setting( 'slidebnlink3', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebnlink3', array(
			'settings'		=> 'slidebnlink3',
			'section'		=> 'medical_portfolio_slider3',
			'type'			=> 'url',
			'label'			=> __( 'Link', 'medical-portfolio' ),
		)
	);		


/*********slide 4*****************/
$wp_customize->add_section('medical_portfolio_slider4', 
array(
    'title' => __('Slide 4', 'medical-portfolio'),
    'description'=> sprintf(__('Slide 4 Details', 'medical-portfolio')),
	'panel'			=> 'medical_portfolio_panel_slider',
    'priority' => 100
    ));
						 
	$wp_customize -> add_setting('slideimg4', array(
		'default' => '', 
		'type' => 'theme_mod',
		'sanitize_callback' => 'medical_portfolio_sanitize_image'

	));

	$wp_customize -> add_control(new WP_Customize_Image_Control($wp_customize, 'slideimg4', array(
		'label' => __( 'Slide 4', 'medical-portfolio'),
		'section' => 'medical_portfolio_slider4',
		'settings' => 'slideimg4',
		'priority' => 2
	))); 

	
	$wp_customize->add_setting( 'slidebntext4', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebntext4', array(
			'settings'		=> 'slidebntext4',
			'section'		=> 'medical_portfolio_slider4',
			'type'			=> 'textarea',
			'label'			=> __( 'Image Text', 'medical-portfolio' ),
		)
	);
	
	$wp_customize->add_setting( 'slidebnlink4', array(
            'default'        => '',
            'sanitize_callback'  => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebnlink4', array(
			'settings'		=> 'slidebnlink4',
			'section'		=> 'medical_portfolio_slider4',
			'type'			=> 'url',
			'label'			=> __( 'Link', 'medical-portfolio' ),
		)
	);		
	}
add_action( 'customize_register', 'medical_portfolio_customize_register' );




/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function medical_portfolio_customize_preview_js() {
	wp_enqueue_script( 'medical_portfolio_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'medical_portfolio_customize_preview_js' );

/************************************
 * sanitization callback.
 ***********************************/
function medical_portfolio_sanitize_css( $css ) {
	return wp_strip_all_tags( $css );
}
function medical_portfolio_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! null( $hex_color ) ? $hex_color : $setting->default );
}
function medical_portfolio_sanitize_select( $input, $setting ) {
	
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}
function medical_portfolio_sanitize_gfont( $input ) {
		if ( in_array($input, array('Helvetica Neue','Helvetica','Raleway','Khula','Open Sans','Indie Flower','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Fjalla One','PT Sans Narrow','Poiret One','Passion One','Arvo','Inconsolata','Shadows Into Light','Pacifico','Dancing Script','Architects Daughter','Sigmar One','Righteous','Amatic SC','Orbitron','Chewy','Lobster Two','Gloria Hallelujah','Lekton','Almendra Display','Swanky and Moo Moo','Hanalei Fill','Uncial Antiqua','Rouge Script','Engagement','Bonbon','Caesar Dressing','Kenia','Lemon','Stardos Stencil','Bilbo','Macondo','Delius Unicase','Butcherman','Monoton','Nosifer','Codystar','Fontdiner Swanky','Diplomata SC','Snowburst One','Faster One','Rock Salt','Eater') ) )
			return $input;
		else
			return '';	
	}
	
	
	function medical_portfolio_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}